Welcome to kedro-pandera's documentation!
========================================

.. toctree::
   :maxdepth: 4

   Tutorial <source/01_tutorials/01_getting_started.md>
   DataFrameModel <source/01_tutorials/02_dataframe_model.md>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
